# Cluster Analysis of Temporal Patterns of Travel Production
## Overview
This repository contains the code, and supplementary materials associated with the research paper titled "A Cluster Analysis of Temporal Patterns of Travel Production in the Netherlands: Dominant within-day and day-to-day patterns and their association with Urbanization Levels". The paper is published in the [EJTIR](https://journals.open.tudelft.nl/ejtir/article/view/6499).

## Table of Contents

- [Introduction](#introduction)
- [Repository Structure](#repository-structure)
- [Installation](#installation)
  - [Prerequisites](#prerequisites)
  - [Setting Up the Environment](#setting-up-the-environment)
- [Usage](#usage)
- [Datasets](#datasets)
- [License](#license)
- [Contact Information](#contact-information)
- [Reproducing Results](#reproducing-results)
- [License](#license)
- [Contact Information](#contact-information)
- [Acknowledgments](#acknowledgments)

## Introduction
This repository includes the implementation of models and analyses presented in the study, which investigates the temporal patterns of travel production in the Netherlands.

## Repository Structure
The repository is organized as follows:
```bash
/project-root
│-- /MiRRORS data                                   # raw input data for the project. As the input data are sensetive, they will not be shared publically
│   │
│-- /dittlabData                                   # input, intermediate and output files for the project. As the these data are sensetive, they will not be shared publically
│   │
│-- /hmaps                                  # the output directory of the project to write the heatmap results in. By running the project from scratch, this folder will be populated but initially, it is empty in the repository. 
|
|-- _7_prod_attraction_Input.py             # 0) This Python script processes Origin-Destination (OD) data to generate matrices and 
statistical analyses, including daily and hourly production metrics for different zones. 
It uses various functions to aggregate and analyze transportation demand data, outputting 
the results as CSV files for further analysis.
|-- _8_attraction_Input.py                  # 1) This Python script processes transportation Origin-Destination (OD) data to generate 
matrices and analyze demand, focusing on calculating the average production and 
attraction during peak hours for different zones. The results are saved as CSV files, 
which can be further analyzed or visualized.
|-- _10_proAttrCV_spatialAgg_entireDay.py   # 2) This Python script processes and analyzes Origin-Destination (OD) data to calculate 
and visualize the coefficient of variation (CV) for motor vehicle production and 
attraction across different spatial levels. The results are saved as CSV files and 
visualized using violin plots to compare variability across zones.
|-- _11_prodAttrCV_temporalAgg_mzr.py       # 3) This Python script analyzes the temporal variability of motor vehicle production 
and attraction across different zones by calculating the coefficient of variation 
(CV) for various time aggregation intervals. The results are visualized using violin 
plots and saved as CSV and PNG files for further analysis.
|-- _19_applyingPCA.ipynb                   # 4) This Python script processes Origin-Destination (OD) data, applying Principal Component Analysis (PCA) to reduce dimensionality and identify the most significant 
OD pairs. The results include cumulative variance explained by PCA components, key 
OD pairs, and transformed data, which are visualized and saved for further analysis.
|-- _23_KmeanswithoutDCNN.ipynb             # 5) This script performs data processing, clustering, and various machine learning tasks, including SVM, MLP, and Boosting algorithms, to classify zones based on land-use variables. 
|-- _24_tryingKmeansWithDCNN.ipynb          # 6) This script processes and analyzes geographic and temporal data to generate various visualizations and statistical analyses, including clustering, time series analysis, and land-use quantification.

|-- _25_productionPrediction.ipynb          # 7)  This script processes traffic and production data, applying statistical models and machine learning techniques to predict production delays. The analysis includes SARIMAX models with various exogenous variables such as land-use features.
|-- _26_productionGraphNeuralNet.ipynb      # 8)  This script processes geographical data for various administrative levels (provinces, municipalities, and mzr zones) in the Netherlands. It generates adjacency matrices and prepares production data for graphical neural network applications.
│-- README.md                               # This README file
|-- LICENSE                                 # This the project LICENSE file            

│-- requirements.txt                        # Python dependencies
```
## Installation
### Prerequisites
- Python >=3.7
- Git
- Jupyter Notebook (if you wish to run the notebooks)
### Setting Up the Environment
- Clone the repository:
  
```bash
# Clone the repository
git clone <repository-url>
# Navigate to the project directory
cd <repository-directory>
```

- Install the required Python packages:
```bash
pip install -r requirements.txt
```
# Usage
To run the code provided in this repository, run the python notebooks acording to the order provided in the naming convention. Please make sure the input data is included in the data directory and the path to the input file is modified accordingly in each script.
# Datasets
The input datasets used in this study should be included in the /data directory. As the project's datasets are either sensitve or too large to include directly in the repository, they can be accessed via TUDelft Research Drive link, or you may need to contact the associated point of contact at the time.

# License
This project is licensed under the MIT License - see the LICENSE file for details.

# Contact Information
For any inquiries, please contact the corresponding author of the paper, [Zahra Eftekhar](mailto: z.eftekhar2016@gmail.com)

# Acknowledgments
This research is sponsored by the NWO/TTW project MiRRORS under grant agreement 16270.


